import { ScrollView, View, Image } from "@tarojs/components";
import "./index.less";
import { ConfigProvider, Flex, Navbar } from "@taroify/core";
import Taro, { useLoad } from "@tarojs/taro";
import { useMemo, useState } from "react";
import icon22 from "@/assets/icon/icon22.png";
import icon23 from "@/assets/icon/icon23.png";
import icon24 from "@/assets/icon/icon24.png";
import icon25 from "@/assets/icon/icon25.png";
import { styles } from "@tarojs/shared/dist/template";

export default function () {
  const [statusBarHeight, setStatusBarHeight] = useState(0);

  const onBack = () => {
    Taro.navigateBack();
  };
  useLoad(() => {
    const systemInfo = Taro.getSystemInfoSync();
    setStatusBarHeight(systemInfo?.statusBarHeight ?? 0);
  });

  const params = Taro.getCurrentInstance().router?.params;

  const info = useMemo(() => {
    const type = params?.type;
    switch (type) {
      case "建议":
        return {
          title: "我的建议",
          robotIcon: icon22,
        };
      case "咨询":
        return {
          title: "我的咨询",
          robotIcon: icon23,
        };
      case "投诉":
        return {
          title: "我的投诉",
          robotIcon: icon24,
        };
      case "举报":
        return {
          title: "我的举报",
          robotIcon: icon25,
        };
      default:
        return undefined;
    }
  }, [params]);

  const demoData = [
    {
      q: "建议加强下水管道渗水排查",
      t: "2024.07.01",
      a: undefined,
    },

    {
      q: "取消光明小区外垃圾投放点的建议",
      t: "2024.07.01",
      ab: "市容环卫科",
      a: "这里是回复描述，这里是回复描述，这里 是回复描述，这里是回复描述。",
    },
    {
      q: "建议尽快实施垃圾分类政策",
      t: "2024.07.01",
      ab: "市容环卫科",
      a: "这里是回复描述，这里是回复描述，这里 是回复描述，这里是回复描述。",
    },
    {
      q: "建议加强下水管道渗水排查",
      t: "2024.07.01",
      ab: "市容环卫科",
      a: "这里是回复描述，这里是回复描述，这里 是回复描述，这里是回复描述。",
    },
    {
      q: "建议加强下水管道渗水排查",
      t: "2024.07.01",
      ab: "市容环卫科",
      a: "这里是回复描述，这里是回复描述，这里 是回复描述，这里是回复描述。",
    },
  ];

  return (
    <View className="report_container">
      <View className="decoration" />
      <View style={{ height: statusBarHeight }} />
      <ConfigProvider
        theme={{
          "—navbar-background-color": "transparent",
        }}
      >
        <Navbar safeArea="top">
          <Navbar.NavLeft onClick={onBack}>返回</Navbar.NavLeft>
        </Navbar>
      </ConfigProvider>
      <View className="title">{info?.title}</View>
      <ScrollView
        scrollY
        style={{ height: `calc(100vh - ${statusBarHeight}px - 94px)` }}
      >
        <View className="contentView">
          {demoData.map((item) => {
            return (
              <View className="reportItemCard">
                <Flex>
                  <Flex.Item span={3}>
                    <Image src={info?.robotIcon} className="robotIcon"></Image>
                  </Flex.Item>
                  <Flex.Item span={21}>
                    <View className="reportTitle">{item.q}</View>
                    <View className="reportTime">{item.t}</View>
                    {item.a ? (
                      <View className="reportAnswer-card">
                        <View className="reportAnswer-title">
                          {item.ab} 回复
                        </View>
                        <View className="reportAnswer-content">{item.a}</View>
                      </View>
                    ) : (
                      <View className="noRecover">待回复...</View>
                    )}
                  </Flex.Item>
                </Flex>
              </View>
            );
          })}
        </View>
      </ScrollView>
    </View>
  );
}
